@@ -14,11 +14,11 @@
 
 from craedl.core import Profile
 
-__version__ = '0.5.3'
+__version__ = '0.5.5'
 
 def auth():
     return Profile()
 
-def configure():
+def configure(token=None):
     from craedl.__main__ import main
-    main()
+    main(token)
